#ifndef SAVESTATESELECT_H
#define SAVESTATESELECT_H

#include <QDialog>
#include <QListWidgetItem>
#include "rominfo.h"

namespace Ui {
class SavestateSelect;
}

class SavestateSelect : public QDialog
{
    Q_OBJECT
    
public:
    explicit SavestateSelect(QWidget *parent = 0, RomInfo* rom=0);
    ~SavestateSelect();

    int Selected();
    int SelectedDisc();

private:
    Ui::SavestateSelect *ui;

    RomInfo* m_Rom;
    QString m_Selected;

    QStringList m_List;
    void FillList();
    QString GetSavestatePath();

private slots:
    void SavestateSelected(QListWidgetItem*);
    void DeleteSavestate();
};

#endif // SAVESTATESELECT_H
